# Docs

## Amount Column

Amount is negative for any income and positive for any expense,
[based on Plaid](https://plaid.com/docs/transactions):

> The settled dollar value. Positive values when money moves out of the account; negative values when money moves in. For example, purchases are positive; credit card payments, direct deposits, refunds are negative.
